# Foo

## Living Standard, 1 January 1970

This version:
  http://example.com/foo
Editor:
  Example Editor

COPYRIGHT GOES HERE

## Abstract

Make sure `, but not too much.`

``

## 1. this shouldn’t have a code

`this should have one code`

`this one already has a code, shouldn’t have a second`

## Index

### Terms defined by this specification

- this one already has a code, shouldn’t have a second, in §1
- this should have one code, in §1
- this shouldn’t have a code, in §Unnumbered section